@@ -3,12 +3,14 @@ import json
 import logging
 
 
-def export_to_json(data, file_path):
+def export_to_json(data, file_path, ensure_ascii=False, indent=4):
     """Exports the data to a json file.
 
     Args:
         data (list[dict]): The data to be exported.
         file_path (str): The path to save the file.
+        ensure_ascii (bool, optional): Whether to ensure the output is ASCII. Defaults to False.
+        indent (int, optional): The number of spaces to indent the output. Defaults to 4.
     """
     # check if the file path ends with .json
     if not file_path.endswith(".json"):
@@ -18,60 +20,10 @@ def export_to_json(data, file_path):
     # write the data to a json file
     with open(file_path, "w") as file:
         logging.info(f"Exporting data to {file_path}...")
-        json.dump(data, file, indent=4)
+        json.dump(data, file, ensure_ascii=ensure_ascii, indent=indent)
         logging.info("Data exported successfully.")
 
 
-# def fix_invalid_keys(data):
-#     """Fixes invalid keys in the data by:
-#         - Replacing periods in the keys with underscores.
-#         - Replacing the spaces in the keys with underscores.
-#         - Replacing the slashes in the keys with bars.
-#         - Replacing the at signs with hashtags.
-#
-#     Args:
-#         data (dict, list[dict]): The data to fix the keys for.
-#
-#     Returns:
-#         dict, list[dict]: The data with the invalid keys replaced.
-#
-#     Raises:
-#         TypeError: If the data is not a dictionary or a list of dictionaries.
-#     """
-    # # replace periods, spaces, and slashes in the keys
-    # if isinstance(data, dict):
-    #     clean_data = {}  # new dictionary to store the data with at signs replaced by underscores
-    #     for key, value in data.items():
-    #         if not key:  # if the key is empty, replace it with an underscore
-    #             key = '_'
-    #         if '@' in key:  # if the key has an at sign, replace it with a hashtag
-    #             key = key.replace('@', '#')
-    #         if '.' in key:  # if the key has a period, replace it with an underscore
-    #             key = key.replace('.', '_')
-    #         if ' ' in key:
-    #             key = key.replace(' ', '_')
-    #         if '/' in key:
-    #             key = key.replace('/', '|')
-    #
-    #         if isinstance(value, (dict, list)):
-    #             clean_data[key] = fix_invalid_keys(value)
-    #         else:
-    #             clean_data[key] = value
-    #
-    #     return clean_data
-    #
-    # elif isinstance(data, list):
-    #     clean_data = []
-    #     for item in data:
-    #         if isinstance(item, dict):
-    #             clean_data.append(fix_invalid_keys(item))
-    #         else:
-    #             clean_data.append(item)
-    #
-    #     return clean_data
-    #
-    # else:
-    #     raise TypeError("Data must be a dictionary or a list of dictionaries.")
 def replace_invalid_keys(data):
     """Replaces invalid characters in the keys of the given data dict or list of dicts.
 
@@ -87,9 +39,13 @@ def replace_invalid_keys(data):
     if isinstance(data, dict):
         new_data = {}
         for key, value in data.items():
-            new_key = key.replace('.', '_').replace(' ', '_').replace('/', '|').replace('@', '#')
+            if key == "":
+                key = "empty_key"
+            new_key = key.replace('.', '_').replace(' ', '_').replace('/', '>').replace('@', '#')
+
             if isinstance(value, (dict, list)):
                 new_data[new_key] = replace_invalid_keys(value)
+
             else:
                 new_data[new_key] = value
 
@@ -100,6 +56,7 @@ def replace_invalid_keys(data):
         for item in data:
             if isinstance(item, (dict, list)):
                 new_data.append(replace_invalid_keys(item))
+
             else:
                 new_data.append(item)
 
@@ -126,6 +83,7 @@ def initialize_logger(file_handler_path=None):
             # check if the path ends with a slash
             if file_handler_path.endswith('/'):
                 file_handler = logging.FileHandler(f"{file_handler_path}{today}.log")
+
             else:
                 file_handler = logging.FileHandler(f"{file_handler_path}/{today}.log")
             # set level to DEBUG
@@ -197,16 +155,20 @@ def parse_to_nldjson(data_to_parse, upload_date=True):
     if isinstance(data_to_parse, dict):
         data_to_parse = [data_to_parse]
 
+    # check if the data is able to be parsed
+    if not isinstance(data_to_parse, list):
+        raise TypeError("Data must be a dictionary or a list of dictionaries.")
+
     # convert to newline delimited json
     if upload_date:  # add upload date to the payload
         logging.info("Adding upload date and converting data to nldjson...")
         for item in data_to_parse:
             item["upload_date"] = datetime.date.today().isoformat()
-            nld_json += f"{json.dumps(item)}\n"
+            nld_json += json.dumps(item) + "\n"
 
     else:  # upload date is not required
         logging.info("Converting data to nldjson...")
         for item in data_to_parse:
-            nld_json += f"{json.dumps(item)}\n"
+            nld_json += json.dumps(item) + "\n"
 
     return nld_json
